aboutsummaryrefslogtreecommitdiffstats
path: root/phpBB/phpbb
diff options
context:
space:
mode:
authorMarc Alexander <admin@m-a-styles.de>2013-09-14 14:04:48 +0200
committerMarc Alexander <admin@m-a-styles.de>2013-09-14 14:04:48 +0200
commit19512b2595cef521099a95b1ab8c24dbe51c5b2f (patch)
treebc3d575b1acfaadb63eefd11501bbab9a525b79b /phpBB/phpbb
parentb810957c4bc4ffa86dd4db4cce26bd49d7008670 (diff)
downloadforums-19512b2595cef521099a95b1ab8c24dbe51c5b2f.tar
forums-19512b2595cef521099a95b1ab8c24dbe51c5b2f.tar.gz
forums-19512b2595cef521099a95b1ab8c24dbe51c5b2f.tar.bz2
forums-19512b2595cef521099a95b1ab8c24dbe51c5b2f.tar.xz
forums-19512b2595cef521099a95b1ab8c24dbe51c5b2f.zip
[feature/passwords] Rename "crypto" files to "passwords" files
PHPBB3-11610
Diffstat (limited to 'phpBB/phpbb')
-rw-r--r--phpBB/phpbb/passwords/driver/base.php (renamed from phpBB/phpbb/crypto/driver/base.php)10
-rw-r--r--phpBB/phpbb/passwords/driver/bcrypt.php (renamed from phpBB/phpbb/crypto/driver/bcrypt.php)4
-rw-r--r--phpBB/phpbb/passwords/driver/bcrypt_2y.php (renamed from phpBB/phpbb/crypto/driver/bcrypt_2y.php)4
-rw-r--r--phpBB/phpbb/passwords/driver/helper.php (renamed from phpBB/phpbb/crypto/driver/helper.php)6
-rw-r--r--phpBB/phpbb/passwords/driver/interface.php (renamed from phpBB/phpbb/crypto/driver/interface.php)4
-rw-r--r--phpBB/phpbb/passwords/driver/phpass.php (renamed from phpBB/phpbb/crypto/driver/phpass.php)4
-rw-r--r--phpBB/phpbb/passwords/driver/salted_md5.php (renamed from phpBB/phpbb/crypto/driver/salted_md5.php)4
-rw-r--r--phpBB/phpbb/passwords/helper.php (renamed from phpBB/phpbb/crypto/helper.php)10
-rw-r--r--phpBB/phpbb/passwords/manager.php (renamed from phpBB/phpbb/crypto/manager.php)18
9 files changed, 32 insertions, 32 deletions
diff --git a/phpBB/phpbb/crypto/driver/bcrypt.php b/phpBB/phpbb/passwords/driver/bcrypt.php
index ad5a8036c3..2c2ab8e7b7 100644
--- a/phpBB/phpbb/crypto/driver/bcrypt.php
+++ b/phpBB/phpbb/passwords/driver/bcrypt.php
@@ -16,9 +16,9 @@ if (!defined('IN_PHPBB'))
}
/**
-* @package crypto
+* @package passwords
*/
-class phpbb_crypto_driver_bcrypt extends phpbb_crypto_driver_base
+class phpbb_passwords_driver_bcrypt extends phpbb_passwords_driver_base
{
const PREFIX = '$2a$';
diff --git a/phpBB/phpbb/crypto/driver/bcrypt_2y.php b/phpBB/phpbb/passwords/driver/bcrypt_2y.php
index 8bce171a25..9277414d13 100644
--- a/phpBB/phpbb/crypto/driver/bcrypt_2y.php
+++ b/phpBB/phpbb/passwords/driver/bcrypt_2y.php
@@ -16,9 +16,9 @@ if (!defined('IN_PHPBB'))
}
/**
-* @package crypto
+* @package passwords
*/
-class phpbb_crypto_driver_bcrypt_2y extends phpbb_crypto_driver_bcrypt
+class phpbb_passwords_driver_bcrypt_2y extends phpbb_passwords_driver_bcrypt
{
const PREFIX = '$2y$';
diff --git a/phpBB/phpbb/crypto/driver/interface.php b/phpBB/phpbb/passwords/driver/interface.php
index 68313fbedd..a019830cb4 100644
--- a/phpBB/phpbb/crypto/driver/interface.php
+++ b/phpBB/phpbb/passwords/driver/interface.php
@@ -16,9 +16,9 @@ if (!defined('IN_PHPBB'))
}
/**
-* @package crypto
+* @package passwords
*/
-interface phpbb_crypto_driver_interface
+interface phpbb_passwords_driver_interface
{
/**
* Check if hash type is supported
diff --git a/phpBB/phpbb/crypto/driver/phpass.php b/phpBB/phpbb/passwords/driver/phpass.php
index 4868464d73..14ba60f279 100644
--- a/phpBB/phpbb/crypto/driver/phpass.php
+++ b/phpBB/phpbb/passwords/driver/phpass.php
@@ -16,9 +16,9 @@ if (!defined('IN_PHPBB'))
}
/**
-* @package crypto
+* @package passwords
*/
-class phpbb_crypto_driver_phpass extends phpbb_crypto_driver_salted_md5
+class phpbb_passwords_driver_phpass extends phpbb_passwords_driver_salted_md5
{
const PREFIX = '$P$';
diff --git a/phpBB/phpbb/crypto/driver/salted_md5.php b/phpBB/phpbb/passwords/driver/salted_md5.php
index c5a8345453..b87daae4e3 100644
--- a/phpBB/phpbb/crypto/driver/salted_md5.php
+++ b/phpBB/phpbb/passwords/driver/salted_md5.php
@@ -16,9 +16,9 @@ if (!defined('IN_PHPBB'))
}
/**
-* @package crypto
+* @package passwords
*/
-class phpbb_crypto_driver_salted_md5 extends phpbb_crypto_driver_base
+class phpbb_passwords_driver_salted_md5 extends phpbb_passwords_driver_base
{
const PREFIX = '$H$';
diff --git a/phpBB/phpbb/crypto/driver/base.php b/phpBB/phpbb/passwords/driver/base.php
index f75031dabd..67cbe4decf 100644
--- a/phpBB/phpbb/crypto/driver/base.php
+++ b/phpBB/phpbb/passwords/driver/base.php
@@ -16,28 +16,28 @@ if (!defined('IN_PHPBB'))
}
/**
-* @package crypto
+* @package passwords
*/
-abstract class phpbb_crypto_driver_base implements phpbb_crypto_driver_interface
+abstract class phpbb_passwords_driver_base implements phpbb_passwords_driver_interface
{
/** @var phpbb_config */
protected $config;
- /** @var phpbb_crypto_driver_helper */
+ /** @var phpbb_passwords_driver_helper */
protected $helper;
/** @var driver name */
protected $name;
/**
* Constructor of crypto driver object
*
* @return string Hash prefix
*/
public function __construct(phpbb_config $config)
{
$this->config = $config;
- $this->helper = new phpbb_crypto_driver_helper($this);
+ $this->helper = new phpbb_passwords_driver_helper($this);
}
/**
@@ -16,28 +16,28 @@ if (!defined('IN_PHPBB'))
protected $name;
/**
- * Constructor of crypto driver object
+ * Constructor of passwords driver object
*
* @return string Hash prefix
diff --git a/phpBB/phpbb/crypto/driver/helper.php b/phpBB/phpbb/passwords/driver/helper.php
index 308ee7dce2..dcd07263d5 100644
--- a/phpBB/phpbb/crypto/driver/helper.php
+++ b/phpBB/phpbb/passwords/driver/helper.php
@@ -16,9 +16,9 @@ if (!defined('IN_PHPBB'))
}
/**
-* @package crypto
+* @package passwords
*/
-class phpbb_crypto_driver_helper
+class phpbb_passwords_driver_helper
{
/** @var phpbb_config */
protected $driver;
@@ -30,7 +30,7 @@ class phpbb_crypto_driver_helper
public $itoa64 = './0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz';
/**
* Constructor of crypto driver helper object
*/
public function __construct($driver)
{
@@ -30,7 +30,7 @@ class phpbb_crypto_driver_helper
public $itoa64 = './0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz';
/**
- * Constructor of crypto driver helper object
+ * Constructor of passwords driver helper object
*/
public function __construct($driver)
diff --git a/phpBB/phpbb/crypto/helper.php b/phpBB/phpbb/passwords/helper.php
index 9c802b3c01..952f491669 100644
--- a/phpBB/phpbb/crypto/helper.php
+++ b/phpBB/phpbb/passwords/helper.php
@@ -16,12 +16,12 @@ if (!defined('IN_PHPBB'))
}
/**
-* @package crypto
+* @package passwords
*/
-class phpbb_crypto_helper
+class phpbb_passwords_helper
{
/**
- * @var phpbb_crypto_manager
+ * @var phpbb_passwords_manager
*/
protected $manager;
@@ -31,9 +31,9 @@ class phpbb_crypto_helper
protected $container;
/**
- * Construct a phpbb_crypto_helper object
+ * Construct a phpbb_passwords_helper object
*
* @param phpbb_crypto_manager $manager Crypto manager object
* @param phpbb_container $container phpBB container object
*/
public function __construct($manager, $container)
@@ -31,9 +31,9 @@ class phpbb_crypto_helper
*
- * @param phpbb_crypto_manager $manager Crypto manager object
+ * @param phpbb_passwords_manager $manager Crypto manager object
* @param phpbb_container $container phpBB container object
*/
diff --git a/phpBB/phpbb/crypto/manager.php b/phpBB/phpbb/passwords/manager.php
index 885bf719bf..9477ef5c2b 100644
--- a/phpBB/phpbb/crypto/manager.php
+++ b/phpBB/phpbb/passwords/manager.php
@@ -16,9 +16,9 @@ if (!defined('IN_PHPBB'))
}
/**
-* @package crypto
+* @package passwords
*/
-class phpbb_crypto_manager
+class phpbb_passwords_manager
{
/**
* Default hashing method
@@ -37,7 +37,7 @@ class phpbb_crypto_manager
/**
* Crypto helper
- * @var phpbb_crypto_helper
+ * @var phpbb_passwords_helper
*/
protected $helper;
@@ -54,7 +54,7 @@ class phpbb_crypto_manager
protected $container;
/**
* Construct a crypto object
*
* @param phpbb_config $config phpBB configuration
*/
@@ -65,7 +65,7 @@ class phpbb_crypto_manager
$this->type = $default;
$this->fill_type_map($hashing_algorithms);
- $this->load_crypto_helper();
+ $this->load_passwords_helper();
}
/**
@@ -85,13 +85,13 @@ class phpbb_crypto_manager
}
/**
* Load crypto helper class
*/
- protected function load_crypto_helper()
+ protected function load_passwords_helper()
{
if ($this->helper === null)
{
- $this->helper = new phpbb_crypto_helper($this, $this->container);
+ $this->helper = new phpbb_passwords_helper($this, $this->container);
}
}
@@ -170,7 +170,7 @@ class phpbb_crypto_manager
$hashing_algorithm = $this->container->get($type);
// Do not support 8-bit characters with $2a$ bcrypt
- if ($type === 'crypto.driver.bcrypt' || ($type === 'crypto.driver.bcrypt_2y' && !$hashing_algorithm->is_supported()))
+ if ($type === 'passwords.driver.bcrypt' || ($type === 'passwords.driver.bcrypt_2y' && !$hashing_algorithm->is_supported()))
{
if (ord($password[strlen($password)-1]) & 128)
{
@@ -54,7 +54,7 @@ class phpbb_crypto_manager
protected $container;
/**
- * Construct a crypto object
+ * Construct a passwords object
*
* @param phpbb_config $config phpBB configuration
@@ -85,13 +85,13 @@ class phpbb_crypto_manager
}
/**
- * Load crypto helper class
+ * Load passwords helper class
*/